﻿// Copyright (C) 2015 Kazuhiro Fujieda <fujieda@users.osdn.me>
//
// This program is part of KancolleSniffer.
//
// KancolleSniffer is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, see <http://www.gnu.org/licenses/>.

using System.Collections.Generic;

namespace KancolleSniffer
{
    internal class MissingData
    {
        public static readonly Dictionary<int, int[]> MaxEq = new Dictionary<int, int[]>
        {
            {501, new[] {0, 0, 0, 0, 0}},
            {502, new[] {0, 0, 0, 0, 0}},
            {503, new[] {0, 0, 0, 0, 0}},
            {504, new[] {0, 0, 0, 0, 0}},
            {505, new[] {1, 1, 0, 0, 0}},
            {506, new[] {1, 1, 0, 0, 0}},
            {507, new[] {2, 2, 2, 0, 0}},
            {508, new[] {2, 2, 2, 0, 0}},
            {509, new[] {3, 3, 3, 0, 0}},
            {510, new[] {18, 18, 18, 0, 0}},
            {511, new[] {3, 3, 3, 0, 0}},
            {512, new[] {27, 27, 27, 0, 0}},
            {513, new[] {0, 0, 0, 0, 0}},
            {514, new[] {0, 0, 0, 0, 0}},
            {515, new[] {0, 0, 0, 0, 0}},
            {516, new[] {0, 0, 0, 0, 0}},
            {517, new[] {0, 0, 0, 0, 0}},
            {518, new[] {1, 1, 0, 0, 0}},
            {519, new[] {1, 1, 0, 0, 0}},
            {520, new[] {2, 2, 2, 0, 0}},
            {521, new[] {2, 2, 2, 0, 0}},
            {522, new[] {3, 3, 3, 3, 0}},
            {523, new[] {24, 24, 24, 0, 0}},
            {524, new[] {3, 3, 3, 3, 0}},
            {525, new[] {30, 30, 30, 0, 0}},
            {526, new[] {0, 0, 0, 0, 0}},
            {527, new[] {4, 4, 4, 4, 0}},
            {528, new[] {32, 32, 32, 0, 0}},
            {529, new[] {5, 5, 5, 5, 0}},
            {530, new[] {0, 0, 0, 0, 0}},
            {531, new[] {0, 0, 0, 0, 0}},
            {532, new[] {0, 0, 0, 0, 0}},
            {533, new[] {0, 0, 0, 0, 0}},
            {534, new[] {0, 0, 0, 0, 0}},
            {535, new[] {0, 0, 0, 0, 0}},
            {536, new[] {30, 30, 30, 0, 0}},
            {537, new[] {30, 30, 30, 0, 0}},
            {538, new[] {30, 30, 30, 0, 0}},
            {539, new[] {60, 60, 60, 0, 0}},
            {540, new[] {60, 60, 60, 0, 0}},
            {541, new[] {4, 4, 4, 4, 0}},
            {542, new[] {4, 4, 4, 4, 0}},
            {543, new[] {4, 4, 4, 4, 0}},
            {544, new[] {80, 80, 0, 0, 0}},
            {545, new[] {96, 96, 0, 0, 0}},
            {546, new[] {0, 0, 50, 0, 0}},
            {547, new[] {0, 70, 70, 0, 0}},
            {548, new[] {0, 0, 90, 0, 0}},
            {549, new[] {0, 35, 35, 0, 0}},
            {550, new[] {0, 35, 35, 0, 0}},
            {551, new[] {0, 35, 35, 0, 0}},
            {552, new[] {0, 0, 0, 0, 0}},
            {553, new[] {0, 0, 0, 0, 0}},
            {554, new[] {2, 2, 2, 2, 0}},
            {555, new[] {2, 2, 2, 2, 0}},
            {556, new[] {98, 98, 98, 98, 0}},
            {557, new[] {0, 0, 0, 0, 0}},
            {558, new[] {0, 0, 0, 0, 0}},
            {559, new[] {1, 1, 1, 0, 0}},
            {560, new[] {22, 22, 22, 22, 0}},
            {561, new[] {0, 0, 0, 140, 0}},
            {562, new[] {0, 0, 0, 180, 0}},
            {563, new[] {0, 0, 0, 0, 0}},
            {564, new[] {0, 0, 0, 0, 0}},
            {565, new[] {36, 36, 36, 36, 0}},
            {566, new[] {4, 4, 4, 4, 0}},
            {567, new[] {5, 5, 5, 5, 0}},
            {568, new[] {0, 0, 0, 0, 0}},
            {569, new[] {0, 0, 0, 0, 0}},
            {570, new[] {0, 0, 0, 0, 0}},
            {571, new[] {0, 0, 0, 0, 0}},
            {572, new[] {0, 0, 0, 0, 0}},
            {573, new[] {80, 80, 80, 80, 0}},
            {574, new[] {90, 90, 90, 90, 0}},
            {575, new[] {0, 0, 0, 0, 0}},
            {576, new[] {0, 0, 0, 0, 0}},
            {577, new[] {0, 0, 0, 0, 0}},
            {578, new[] {0, 0, 0, 0, 0}},
            {579, new[] {32, 32, 27, 5, 0}},
            {580, new[] {0, 0, 0, 0, 0}},
            {581, new[] {0, 72, 64, 36, 0}},
            {582, new[] {0, 72, 80, 40, 0}},
            {583, new[] {0, 64, 58, 58, 0}},
            {584, new[] {0, 84, 96, 0, 0}},
            {585, new[] {48, 48, 48, 0, 0}},
            {586, new[] {60, 52, 56, 0, 0}},
            {587, new[] {0, 72, 64, 36, 0}},
            {588, new[] {0, 72, 72, 40, 0}},
            {589, new[] {0, 64, 48, 36, 0}},
            {590, new[] {0, 64, 68, 40, 0}},
            {591, new[] {0, 0, 3, 3, 0}},
            {592, new[] {0, 0, 3, 3, 0}},
            {593, new[] {0, 0, 0, 0, 0}},
            {594, new[] {0, 0, 0, 4, 0}},
            {595, new[] {0, 0, 0, 4, 0}},
            {596, new[] {0, 0, 0, 0, 0}},
            {597, new[] {0, 0, 0, 0, 0}},
            {598, new[] {0, 0, 0, 0, 0}},
            {599, new[] {66, 60, 60, 0, 0}},
            {600, new[] {66, 60, 60, 0, 0}},
            {601, new[] {0, 0, 0, 3, 0}},
            {602, new[] {0, 0, 0, 3, 0}},
            {603, new[] {0, 0, 0, 6, 0}},
            {604, new[] {0, 0, 0, 6, 0}},
            {605, new[] {0, 0, 90, 90, 0}},
            {606, new[] {0, 0, 108, 108, 0}},
            {607, new[] {0, 0, 108, 108, 0}},
            {608, new[] {0, 0, 130, 130, 0}},
            {609, new[] {0, 0, 0, 120, 0}},
            {610, new[] {0, 0, 0, 140, 0}},
            {611, new[] {0, 0, 0, 160, 0}},
            {612, new[] {0, 0, 0, 180, 0}},
            {613, new[] {0, 0, 0, 180, 0}},
            {901, new[] {1, 1, 0, 0, 0}},
            {902, new[] {1, 1, 1, 0, 0}},
            {903, new[] {0, 0, 0, 0, 0}},
            {904, new[] {9, 24, 5, 0, 0}},
            {905, new[] {18, 28, 6, 3, 0}},
            {906, new[] {0, 0, 0, 0, 0}},
            {907, new[] {0, 0, 0, 0, 0}},
            {908, new[] {0, 0, 0, 0, 0}},
            {909, new[] {0, 0, 0, 0, 0}},
            {910, new[] {0, 0, 0, 0, 0}},
            {911, new[] {0, 6, 6, 0, 0}},
            {912, new[] {0, 6, 6, 0, 0}},
            {913, new[] {0, 0, 0, 0, 0}},
            {914, new[] {0, 0, 0, 0, 0}},
            {915, new[] {0, 0, 0, 0, 0}},
            {916, new[] {0, 0, 0, 0, 0}},
            {917, new[] {0, 0, 0, 0, 0}},
            {918, new[] {18, 9, 3, 0, 0}},
            {919, new[] {0, 0, 0, 0, 0}},
        };
    }
}